@@ -18,14 +18,23 @@ data_dir = os.path.join(test_dir, 'data')
 
 
 # tests
-def test_main():
-    genomeList = os.path.join(data_dir, 'genome_list.txt')
-    output_prefix = os.path.join(data_dir, 'comm')
-    args = [genomeList, output_prefix, '--n-comm', 2, '--rnd-seed', 34847]
-    Communities_CMD.opt_parse(args)
+def test_help(script_runner):
+    ret = script_runner.run('MGSIM', 'communities', '-h')
+    assert ret.success
 
-def test_main_ncomm1():
+def test_main(script_runner):
     genomeList = os.path.join(data_dir, 'genome_list.txt')
     output_prefix = os.path.join(data_dir, 'comm')
-    args = [genomeList, output_prefix, '--n-comm', 1, '--richness', 1]
-    Communities_CMD.opt_parse(args)
+    ret = script_runner.run('MGSIM', 'communities',
+                            genomeList, output_prefix,
+                            '--n-comm', '2', '--rnd-seed', '34847')
+    assert ret.success
+
+def test_main_ncomm1(script_runner):
+    genomeList = os.path.join(data_dir, 'genome_list.txt')
+    output_prefix = os.path.join(data_dir, 'comm')
+    ret = script_runner.run('MGSIM', 'communities',
+                            genomeList, output_prefix,
+                            '--n-comm', '1', '--richness', '1')
+    assert ret.success
+
